pub struct CrateConfig { /* private fields */ }Expand description
Configuration for creating a mock crate in the workspace.
Implementations
Sourceimpl CrateConfig
impl CrateConfig
pub fn name(&self) -> &String
pub fn add_readme(&self) -> &bool
pub fn add_src_files(&self) -> &bool
pub fn add_test_files(&self) -> &bool
Sourcepub fn src_file_content(&self) -> &Option<String>
pub fn src_file_content(&self) -> &Option<String>
(new) Optionally store custom content to write into src/main.rs
Sourceimpl CrateConfig
impl CrateConfig
Sourcepub fn new(name: &str) -> CrateConfig
pub fn new(name: &str) -> CrateConfig
Create a new CrateConfig with the given crate name.
Sourcepub fn with_src_files_content<S>(self, content: S) -> CrateConfig
pub fn with_src_files_content<S>(self, content: S) -> CrateConfig
(new) Provide custom Rust code for src/main.rs
Sourcepub fn with_readme(self) -> CrateConfig
pub fn with_readme(self) -> CrateConfig
Set whether to add a README.md file.
Sourcepub fn with_src_files(self) -> CrateConfig
pub fn with_src_files(self) -> CrateConfig
Set whether to add source files in the src/ directory.
Sourcepub fn with_test_files(self) -> CrateConfig
pub fn with_test_files(self) -> CrateConfig
Set whether to add test files in the tests/ directory.
Sourcepub fn has_readme(&self) -> bool
pub fn has_readme(&self) -> bool
Accessor to check if README.md is to be added.
Sourcepub fn has_src_files(&self) -> bool
pub fn has_src_files(&self) -> bool
Accessor to check if src/ files are to be added.
Sourcepub fn has_test_files(&self) -> bool
pub fn has_test_files(&self) -> bool
Accessor to check if test files are to be added.