pub struct CrateInterfaceItemBuilder<T>where
T: GenerateSignature,{ /* private fields */ }Expand description
Builder for CrateInterfaceItem.
Implementations
Sourceimpl<T> CrateInterfaceItemBuilder<T>where
T: GenerateSignature + Clone,
impl<T> CrateInterfaceItemBuilder<T>where
T: GenerateSignature + Clone,
pub fn item<VALUE>(&mut self, value: VALUE) -> &mut CrateInterfaceItemBuilder<T>
pub fn docs<VALUE>(&mut self, value: VALUE) -> &mut CrateInterfaceItemBuilder<T>
pub fn attributes<VALUE>( &mut self, value: VALUE, ) -> &mut CrateInterfaceItemBuilder<T>
pub fn body_source<VALUE>( &mut self, value: VALUE, ) -> &mut CrateInterfaceItemBuilder<T>
pub fn consolidation_options<VALUE>( &mut self, value: VALUE, ) -> &mut CrateInterfaceItemBuilder<T>
Sourcepub fn file_path<VALUE>(
&mut self,
value: VALUE,
) -> &mut CrateInterfaceItemBuilder<T>
pub fn file_path<VALUE>( &mut self, value: VALUE, ) -> &mut CrateInterfaceItemBuilder<T>
The file path from which this item was parsed
Sourcepub fn crate_path<VALUE>(
&mut self,
value: VALUE,
) -> &mut CrateInterfaceItemBuilder<T>
pub fn crate_path<VALUE>( &mut self, value: VALUE, ) -> &mut CrateInterfaceItemBuilder<T>
The crate root path for the crate that owns this item
Sourcepub fn raw_syntax_range<VALUE>(
&mut self,
value: VALUE,
) -> &mut CrateInterfaceItemBuilder<T>
pub fn raw_syntax_range<VALUE>( &mut self, value: VALUE, ) -> &mut CrateInterfaceItemBuilder<T>
The full syntax node range, exactly matching RA’s node range.
Many tests expect this to match node.text_range().
Sourcepub fn effective_item_range<VALUE>(
&mut self,
value: VALUE,
) -> &mut CrateInterfaceItemBuilder<T>
pub fn effective_item_range<VALUE>( &mut self, value: VALUE, ) -> &mut CrateInterfaceItemBuilder<T>
A trimmed range that excludes leading/trailing normal line comments, block comments, and whitespace—but keeps doc comments. We use this for interstitial segment calculations, so “normal” comments appear in the leftover text.
Sourcepub fn build(
&self,
) -> Result<CrateInterfaceItem<T>, CrateInterfaceItemBuilderError>
pub fn build( &self, ) -> Result<CrateInterfaceItem<T>, CrateInterfaceItemBuilderError>