pub struct GatherCommentsState { /* private fields */ }Expand description
Tracks what we’ve collected and where we are in the scanning process.
Implementations
Sourceimpl GatherCommentsState
impl GatherCommentsState
Sourcepub fn set_collected(&mut self, val: Vec<String>) -> &mut GatherCommentsState
pub fn set_collected(&mut self, val: Vec<String>) -> &mut GatherCommentsState
The collected comment lines in top-to-bottom order.
Sourcepub fn set_found_comment(&mut self, val: bool) -> &mut GatherCommentsState
pub fn set_found_comment(&mut self, val: bool) -> &mut GatherCommentsState
Whether we’ve already found a comment during the climb.
Sourcepub fn set_whitespace_newlines_since_last_nonws(
&mut self,
val: usize,
) -> &mut GatherCommentsState
pub fn set_whitespace_newlines_since_last_nonws( &mut self, val: usize, ) -> &mut GatherCommentsState
How many newlines have appeared since the last non-whitespace item.
Sourceimpl GatherCommentsState
impl GatherCommentsState
Sourcepub fn collected_mut(&mut self) -> &mut Vec<String>
pub fn collected_mut(&mut self) -> &mut Vec<String>
The collected comment lines in top-to-bottom order.
Sourcepub fn found_comment_mut(&mut self) -> &mut bool
pub fn found_comment_mut(&mut self) -> &mut bool
Whether we’ve already found a comment during the climb.
Sourcepub fn whitespace_newlines_since_last_nonws_mut(&mut self) -> &mut usize
pub fn whitespace_newlines_since_last_nonws_mut(&mut self) -> &mut usize
How many newlines have appeared since the last non-whitespace item.
Sourceimpl GatherCommentsState
impl GatherCommentsState
Sourcepub fn found_comment(&self) -> &bool
pub fn found_comment(&self) -> &bool
Whether we’ve already found a comment during the climb.
Sourcepub fn whitespace_newlines_since_last_nonws(&self) -> &usize
pub fn whitespace_newlines_since_last_nonws(&self) -> &usize
How many newlines have appeared since the last non-whitespace item.
Sourceimpl GatherCommentsState
impl GatherCommentsState
pub fn new() -> GatherCommentsState