pub struct InterstitialSegment { /* private fields */ }Implementations
Sourceimpl InterstitialSegment
impl InterstitialSegment
Sourcepub fn set_text_range(&mut self, val: TextRange) -> &mut InterstitialSegment
pub fn set_text_range(&mut self, val: TextRange) -> &mut InterstitialSegment
The text range in the file where this raw segment occurs. This segment is anything that does NOT directly belong to a recognized AST item.
Sourcepub fn set_text(&mut self, val: String) -> &mut InterstitialSegment
pub fn set_text(&mut self, val: String) -> &mut InterstitialSegment
The raw text that was found in this range, including whitespace/comments/etc.
Sourcepub fn set_file_path(&mut self, val: PathBuf) -> &mut InterstitialSegment
pub fn set_file_path(&mut self, val: PathBuf) -> &mut InterstitialSegment
The file from which this segment was parsed
Sourcepub fn set_crate_path(&mut self, val: PathBuf) -> &mut InterstitialSegment
pub fn set_crate_path(&mut self, val: PathBuf) -> &mut InterstitialSegment
The crate path from which this file originated
Sourceimpl InterstitialSegment
impl InterstitialSegment
Sourcepub fn text_range(&self) -> &TextRange
pub fn text_range(&self) -> &TextRange
The text range in the file where this raw segment occurs. This segment is anything that does NOT directly belong to a recognized AST item.
Sourcepub fn text(&self) -> &String
pub fn text(&self) -> &String
The raw text that was found in this range, including whitespace/comments/etc.
Sourcepub fn crate_path(&self) -> &PathBuf
pub fn crate_path(&self) -> &PathBuf
The crate path from which this file originated