pub struct InterstitialSegmentBuilder { /* private fields */ }Expand description
Builder for InterstitialSegment.
Implementations
Sourceimpl InterstitialSegmentBuilder
impl InterstitialSegmentBuilder
Sourcepub fn text_range<VALUE>(
&mut self,
value: VALUE,
) -> &mut InterstitialSegmentBuilder
pub fn text_range<VALUE>( &mut self, value: VALUE, ) -> &mut InterstitialSegmentBuilder
The text range in the file where this raw segment occurs. This segment is anything that does NOT directly belong to a recognized AST item.
Sourcepub fn text<VALUE>(&mut self, value: VALUE) -> &mut InterstitialSegmentBuilder
pub fn text<VALUE>(&mut self, value: VALUE) -> &mut InterstitialSegmentBuilder
The raw text that was found in this range, including whitespace/comments/etc.
Sourcepub fn file_path<VALUE>(
&mut self,
value: VALUE,
) -> &mut InterstitialSegmentBuilder
pub fn file_path<VALUE>( &mut self, value: VALUE, ) -> &mut InterstitialSegmentBuilder
The file from which this segment was parsed
Sourcepub fn crate_path<VALUE>(
&mut self,
value: VALUE,
) -> &mut InterstitialSegmentBuilder
pub fn crate_path<VALUE>( &mut self, value: VALUE, ) -> &mut InterstitialSegmentBuilder
The crate path from which this file originated
Sourcepub fn build(
&self,
) -> Result<InterstitialSegment, InterstitialSegmentBuilderError>
pub fn build( &self, ) -> Result<InterstitialSegment, InterstitialSegmentBuilderError>